@@ -29,6 +29,7 @@
 
 #include <string.h>
 #include <glib.h>
+#include <glib/gstdio.h>
 
 #include "gnome-i18nP.h"
 
@@ -97,7 +98,7 @@ gnome_help_display (const char    *file_name,
 /**
  * gnome_help_display_with_doc_id_and_env:
  * @program: The current application object, or %NULL for the default one.
- * @doc_id: The document identifier, or %NULL to default to the application ID
+ * @doc_id: The document identifier, or %NULL to default to empty string.
  * (app_id) of the specified @program.
  * @file_name: The name of the help document to display.
  * @link_id: Can be %NULL. If set, refers to an anchor or section id within the
@@ -112,6 +113,8 @@ gnome_help_display (const char    *file_name,
  *
  * Returns: %TRUE on success, %FALSE otherwise (in which case @error will
  * contain the actual error).
+ *
+ * Since: 2.2
  **/
 gboolean
 gnome_help_display_with_doc_id_and_env (GnomeProgram  *program,
@@ -127,6 +130,7 @@ gnome_help_display_with_doc_id_and_env (GnomeProgram  *program,
 	struct stat local_help_st;
 	struct stat global_help_st;
 	gchar *uri;
+	gchar *free_doc_id = NULL;
 	gboolean retval;
 
 	g_return_val_if_fail (file_name != NULL, FALSE);
@@ -141,8 +145,15 @@ gnome_help_display_with_doc_id_and_env (GnomeProgram  *program,
 	if (program == NULL)
 		program = gnome_program_get ();
 
+	g_assert (program != NULL);
+
+	if (doc_id == NULL) {
+		g_object_get (program, GNOME_PARAM_APP_ID, &doc_id, NULL);
+		free_doc_id = doc_id;
+	}
+
 	if (doc_id == NULL)
-		doc_id = gnome_program_get_app_id (program);
+		doc_id = "";
 
 	/* Compute the local and global help paths */
 
@@ -177,7 +188,7 @@ gnome_help_display_with_doc_id_and_env (GnomeProgram  *program,
 	 * and then falling back to the global help path if the first one fails.
 	 */
 
-	if (stat (local_help_path, &local_help_st) == 0) {
+	if (g_stat (local_help_path, &local_help_st) == 0) {
 		if (!S_ISDIR (local_help_st.st_mode)) {
 			g_set_error (error,
 				     GNOME_HELP_ERROR,
@@ -192,7 +203,7 @@ gnome_help_display_with_doc_id_and_env (GnomeProgram  *program,
 	}
 
 	if (file == NULL) {
-		if (stat (global_help_path, &global_help_st) == 0) {
+		if (g_stat (global_help_path, &global_help_st) == 0) {
 			if (!S_ISDIR (global_help_st.st_mode)) {
 				g_set_error (error,
 					     GNOME_HELP_ERROR,
@@ -240,6 +251,7 @@ gnome_help_display_with_doc_id_and_env (GnomeProgram  *program,
 
  out:
 
+	g_free (free_doc_id);
 	g_free (local_help_path);
 	g_free (global_help_path);
 	g_free (file);
@@ -305,6 +317,8 @@ gnome_help_display_with_doc_id (GnomeProgram  *program,
  *
  * Returns: %TRUE on success, %FALSE otherwise (in which case @error will
  * contain the actual error).
+ *
+ * Since: 2.2
  */
 gboolean
 gnome_help_display_desktop_with_env (GnomeProgram  *program,
@@ -425,6 +439,8 @@ gnome_help_display_desktop (GnomeProgram  *program,
  *
  * Returns: %TRUE on success, %FALSE otherwise (in which case @error will
  * contain the actual error).
+ *
+ * Since: 2.2
  */
 gboolean
 gnome_help_display_uri_with_env (const char  *help_uri,
